BoomHashMap2

Struct BoomHashMap2 

pub struct BoomHashMap2<K: Hash, D1, D2> { /* private fields */ }
A HashMap data structure where the mapping between keys and 2 values is encoded in a Mphf. You should usually use BoomHashMap with a tuple/struct value type. If the layout overhead of the struct / tuple must be avoided, this variant of is an alternative. This lets us store the keys and values in dense arrays, with ~3 bits/item overhead in the Mphf.

Implementations

Source

impl<K, D1, D2> BoomHashMap2<K, D1, D2>
where K: Hash + Debug + PartialEq, D1: Debug, D2: Debug,

pub fn new( keys: Vec<K>, values: Vec<D1>, aux_values: Vec<D2>, ) -> BoomHashMap2<K, D1, D2>

Create a new hash map from the parallel arrays keys and values, and aux_values

pub fn get<Q>(&self, kmer: &Q) -> Option<(&D1, &D2)>
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

pub fn get_mut<Q>(&mut self, kmer: &Q) -> Option<(&mut D1, &mut D2)>
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

pub fn get_key_id<Q>(&self, kmer: &Q) -> Option<usize>
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn iter(&self) -> Boom2Iterator<'_, K, D1, D2>

pub fn get_key(&self, id: usize) -> Option<&K>

Source

impl<K, D1, D2> BoomHashMap2<K, D1, D2>
where K: Hash + Debug + PartialEq + Send + Sync, D1: Debug, D2: Debug,

pub fn new_parallel( keys: Vec<K>, data: Vec<D1>, aux_data: Vec<D2>, ) -> BoomHashMap2<K, D1, D2>

Create a new hash map from the parallel arrays keys and values, and aux_values, using a parallel algorithm to construct the Mphf.