pub struct NoKeyBoomHashMap2<K, D1, D2> {
pub mphf: Mphf<K>,
pub values: Vec<D1>,
pub aux_values: Vec<D2>,
}Expand description
A HashMap data structure where the mapping between keys and values is encoded in a Mphf. Keys are not stored - this can greatly improve the memory consumption, but can only be used if you can guarantee that you will only query for keys that were in the original set. Querying for a new key will return a random value, silently.
Fields
mphf: Mphf<K>values: Vec<D1>aux_values: Vec<D2>Implementations
Sourceimpl<K, D1, D2> NoKeyBoomHashMap2<K, D1, D2>
impl<K, D1, D2> NoKeyBoomHashMap2<K, D1, D2>
pub fn new( keys: Vec<K>, values: Vec<D1>, aux_values: Vec<D2>, ) -> NoKeyBoomHashMap2<K, D1, D2>
pub fn new_parallel( keys: Vec<K>, values: Vec<D1>, aux_values: Vec<D2>, ) -> NoKeyBoomHashMap2<K, D1, D2>
pub fn new_with_mphf( mphf: Mphf<K>, values: Vec<D1>, aux_values: Vec<D2>, ) -> NoKeyBoomHashMap2<K, D1, D2>
Sourcepub fn get<Q>(&self, kmer: &Q) -> Option<(&D1, &D2)>
pub fn get<Q>(&self, kmer: &Q) -> Option<(&D1, &D2)>
Get the value associated with key. You must use a key that was supplied during the creation of the BoomHashMap. Querying for a new key will yield Some with a random value, or None. Querying with a valid key will always return Some.
Sourcepub fn get_mut<Q>(&mut self, kmer: &Q) -> Option<(&mut D1, &mut D2)>
pub fn get_mut<Q>(&mut self, kmer: &Q) -> Option<(&mut D1, &mut D2)>
Mutably get the value associated with key. You must use a key that was supplied during the creation of the BoomHashMap. Querying for a new key will yield Some with a random value, or None. Querying with a valid key will always return Some.